@@ -33,13 +33,13 @@
 #include "iso5426converter.h"
 #include <kdebug.h>
 
-#include <qstring.h>
+#include <ntqstring.h>
 
 using KBibTeX::Iso5426Converter;
 
-QString Iso5426Converter::toUtf8(const QCString& text_) {
+TQString Iso5426Converter::toUtf8(const TQCString& text_) {
   const uint len = text_.length();
-  QString result;
+  TQString result;
   result.reserve(len);
   uint pos = 0;
   for(uint i = 0; i < len; ++i) {
@@ -53,7 +53,7 @@ QString Iso5426Converter::toUtf8(const QCString& text_) {
       if(c == 0xC9) {
         c = 0xC8;
       }
-      QChar d = getCombiningChar(c * 256 + text_[i + 1]);
+      TQChar d = getCombiningChar(c * 256 + text_[i + 1]);
       if(!d.isNull()) {
         result[pos++] = d;
         ++i;
@@ -84,7 +84,7 @@ bool Iso5426Converter::isCombining(uchar c) {
 }
 
 // Source : http://www.itscj.ipsj.or.jp/ISO-IR/053.pdf
-QChar Iso5426Converter::getChar(uchar c) {
+TQChar Iso5426Converter::getChar(uchar c) {
   switch(c) {
   case 0xA1:
     return 0x00A1; // 2/1 inverted exclamation mark
@@ -199,7 +199,7 @@ QChar Iso5426Converter::getChar(uchar c) {
   }
 }
 
-QChar Iso5426Converter::getCombiningChar(uint c) {
+TQChar Iso5426Converter::getCombiningChar(uint c) {
   switch(c) {
   // 4/0 low rising tone mark
   case 0xC041:
@@ -887,6 +887,6 @@ QChar Iso5426Converter::getCombiningChar(uint c) {
 
   default:
     kdDebug() << "Iso5426Converter::getCombiningChar() - no match for " << c << endl;
-    return QChar();
+    return TQChar();
   }
 }
